@@ -6,7 +6,7 @@ from composer.models.efficientnetb0.model import EfficientNetB0 as EfficientNetB
 _task = 'Image Classification'
 _dataset = 'ImageNet'
 _name = 'EfficientNet-B0'
-_quality = ''
+_quality = '76.63'
 _metric = 'Top-1 Accuracy'
-_ttt = '?'
-_hparams = 'hparams.yaml'
+_ttt = '21h 48m'
+_hparams = 'efficientnetb0.yaml'
