@@ -7,7 +7,7 @@ from typing import TYPE_CHECKING, Mapping
 from torchmetrics.collections import MetricCollection
 
 from composer.models.nlp_metrics import Perplexity
-from composer.models.transformer_shared import MosaicTransformer
+from composer.models.transformer_shared import ComposerTransformer
 
 if TYPE_CHECKING:
     import transformers
@@ -15,8 +15,8 @@ if TYPE_CHECKING:
     from composer.core.types import Batch, Metrics, Tensors
 
 
-class GPT2Model(MosaicTransformer):
-    """Implements a GPT-2 wrapper around a MosaicTransformer.
+class GPT2Model(ComposerTransformer):
+    """Implements a GPT-2 wrapper around a :class:`ComposerTransformer`.
 
     See this `paper <https://d4mucfpksywv.cloudfront.net/better-language-models/language-models.pdf>`_
     for details on the GPT-2 architecutre.
@@ -24,15 +24,20 @@ class GPT2Model(MosaicTransformer):
     Args:
         module (transformers.GPT2Model): The model to wrap with this module.
         config (transformers.GPT2Config): The config for the model.
-        tokenizer_name (str): The name of the tokenizer used for tihs model,
+        tokenizer (transformers.GPT2Tokenizer): The tokenizer used for this model,
             necessary to assert required model inputs.
     """
 
-    def __init__(self, module: transformers.GPT2Model, config: transformers.GPT2Config, tokenizer_name: str) -> None:
+    def __init__(self,
+                 module: transformers.GPT2Model,
+                 config: transformers.GPT2Config,
+                 tokenizer: transformers.GPT2Tokenizer,
+                 gradient_checkpointing: bool = False) -> None:
         super().__init__(
             module=module,  #type: ignore (thirdparty)
             config=config,
-            tokenizer_name=tokenizer_name)
+            tokenizer=tokenizer,
+            gradient_checkpointing=gradient_checkpointing)
 
         # If we ever have algorithms that modify the loss function, then this might be a bit inefficient
         #  because it'll compute the expensive softmax operation twice.
@@ -42,7 +47,6 @@ class GPT2Model(MosaicTransformer):
         self.val_perplexity = Perplexity()
 
     def loss(self, outputs: Mapping, batch: Batch) -> Tensors:
-
         if outputs.get('loss', None) is not None:
             return outputs['loss']
         else:
