@@ -8,5 +8,5 @@ _dataset = 'CIFAR10'
 _name = 'ResNet56'
 _quality = '93.1'
 _metric = 'Top-1 Accuracy'
-_ttt = '15m'
+_ttt = 'tbd'
 _hparams = 'resnet56_cifar10.yaml'
