@@ -2,38 +2,38 @@
 
 import contextlib
 import logging
+import textwrap
 from typing import Any, Optional, Tuple
 
 import torch
 import torch.nn as nn
 
 from composer.core.types import BatchPair, Metrics, Tensor, Tensors
-from composer.models.base import BaseMosaicModel
+from composer.models.base import ComposerModel
 from composer.models.loss import Dice
 from composer.models.unet.model import UNet as UNetModel
-from composer.models.unet.unet_hparams import UnetHparams
 
 log = logging.getLogger(__name__)
 
 
-class UNet(BaseMosaicModel):
-    """A U-Net model extending :class:`MosaicClassifier`.
+class UNet(ComposerModel):
+    """A U-Net model extending :class:`ComposerClassifier`.
 
-    See this `paper <https://arxiv.org/abs/1505.04597>`_ for details on the
-    U-Net architecture.
-
-    Args:
-        hparams (UnetHparams): The hyperparameters for constructing the model.
+    See this `paper <https://arxiv.org/abs/1505.04597>`_ for details on the U-Net architecture.
     """
 
     n_classes: Optional[int] = None
 
-    def __init__(self, hparams: UnetHparams) -> None:
+    def __init__(self) -> None:
         super().__init__()
+        try:
+            from monai.losses import DiceLoss
+        except ImportError as e:
+            raise ImportError(
+                textwrap.dedent("""\
+                Composer was installed without unet support. To use timm with Composer, run `pip install mosaicml[unet]`
+                if using pip or `conda install -c conda-forge monai` if using Anaconda.""")) from e
 
-        from monai.losses import DiceLoss
-
-        self.hparams = hparams
         self.module = self.build_nnunet()
 
         self.dice = Dice(3)
@@ -61,7 +61,7 @@ class UNet(BaseMosaicModel):
         return self.dice
 
     def forward(self, batch: BatchPair) -> Tensor:
-        x, y = batch
+        x, _ = batch
         context = contextlib.nullcontext if self.training else torch.no_grad
 
         x = x.squeeze(1)  # type: ignore
