@@ -30,9 +30,7 @@ class OptimizerHparams(hp.Hparams, ABC):
 
 @dataclass
 class AdamHparams(OptimizerHparams):
-    """Hyperparameters for the `Adam <https://pytorch.org/docs/stable/generated/torch.optim.Adam.html#torch.optim.Adam>`_
-    optimizer.
-    """
+    """Hyperparameters for the :class:`~torch.optim.Adam` optimizer."""
     lr: float = hp.optional(default=0.001, doc='learning rate')
     betas: List[float] = hp.optional(default_factory=lambda: [0.9, 0.999],
                                      doc='coefficients used for computing running averages of gradient and its square.')
@@ -47,9 +45,7 @@ class AdamHparams(OptimizerHparams):
 
 @dataclass
 class RAdamHparams(OptimizerHparams):
-    """Hyperparameters for the `RAdam <https://pytorch.org/docs/1.10./generated/torch.optim.RAdam.html#torch.optim.RAdam>`_
-    optimizer.
-    """
+    """Hyperparameters for the :class:`~torch.optim.RAdam` optimizer."""
     lr: float = hp.optional(default=0.001, doc='learning rate')
     betas: List[float] = hp.optional(default_factory=lambda: [0.9, 0.999],
                                      doc='coefficients used for computing running averages of gradient and its square.')
@@ -63,9 +59,7 @@ class RAdamHparams(OptimizerHparams):
 
 @dataclass
 class AdamWHparams(OptimizerHparams):
-    """Hyperparameters for the `AdamW <https://pytorch.org/docs/stable/generated/torch.optim.AdamW.html#torch.optim.AdamW>`_
-    optimizer.
-    """
+    """Hyperparameters for the :class:`torch.optim.AdamW` optimizer."""
     lr: float = hp.optional(default=0.001, doc='learning rate')
     betas: List[float] = hp.optional(default_factory=lambda: [0.9, 0.999],
                                      doc='coefficients used for computing running averages of gradient and its square.')
@@ -96,8 +90,7 @@ class DecoupledAdamWHparams(OptimizerHparams):
 @dataclass
 class SGDHparams(OptimizerHparams):
     """Hyperparameters for the `SGD <https://pytorch.org/docs/stable/generated/torch.optim.SGD.html#torch.optim.SGD>`_
-    optimizer.
-    """
+    optimizer."""
     lr: float = hp.required(doc='learning rate')
     momentum: float = hp.optional(default=0.0, doc='momentum factor')
     weight_decay: float = hp.optional(default=0.0, doc='weight decay (L2 penalty)')
@@ -125,7 +118,8 @@ class DecoupledSGDWHparams(OptimizerHparams):
 
 @dataclass
 class RMSPropHparams(OptimizerHparams):
-    """Hyperparameters for the [RMSProp optimizer](https://pytorch.org/docs/stable/generated/torch.optim.RMSprop.html#torch.optim.RMSprop)."""
+    """Hyperparameters for the [RMSProp
+    optimizer](https://pytorch.org/docs/stable/generated/torch.optim.RMSprop.html#torch.optim.RMSprop)."""
     lr: float = hp.required(doc='learning rate')
     alpha: float = hp.optional(default=0.99, doc='smoothing constant')
     eps: float = hp.optional(default=1e-8, doc='term for numerical stability')
